@@ -5,7 +5,7 @@ from operator import mul
 import numpy
 from sklearn import model_selection
 
-from sklearn_cv_pandas import model
+from . import model
 
 
 logger = logging.getLogger(__name__)
@@ -15,13 +15,17 @@ class RandomizedSearchCV(model_selection.RandomizedSearchCV):
     """
     sklearn.model_selection.RandomizedSearchCV with pandas DataFrame interface
     """
-    def __init__(self, *args, **kwargs):
+    def __init__(self, estimator, param_distributions, n_iter=10, scoring=None, n_jobs=None, pre_dispatch='2*n_jobs',
+                 cv=None, refit=True, verbose=10, random_state=None, error_score=numpy.nan, return_train_score=True):
         """
-        The same manner as [sklearn.model_selection.RandomizedSearchCV](https://scikit-learn.org/stable/modules/generated/sklearn.model_selection.RandomizedSearchCV.html)
+        The same manner as [sklearn.model_selection.RandomizedSearchCV](
+        https://scikit-learn.org/stable/modules/generated/sklearn.model_selection.RandomizedSearchCV.html)
         """
-        kwargs["return_train_score"] = True
-        kwargs["verbose"] = 10
-        super(RandomizedSearchCV, self).__init__(*args, **kwargs)
+        super(RandomizedSearchCV, self).__init__(
+            estimator, param_distributions, n_iter=n_iter, scoring=scoring, n_jobs=n_jobs, pre_dispatch=pre_dispatch,
+            cv=cv, refit=refit, verbose=verbose, random_state=random_state, error_score=error_score,
+            return_train_score=return_train_score
+        )
 
     def fit_sv_pandas(self, df_training, target_column, feature_columns,
                       df_validation=None, ratio_training=None, **kwargs):
@@ -36,7 +40,7 @@ class RandomizedSearchCV(model_selection.RandomizedSearchCV):
             **kwargs: Other keyword arguments for original `fit`
 
         Returns:
-            sklearn_cv_pandas.Model
+            conjurer.ml.Model
         """
         x, y, num_training, num_validation = _split_for_sv(
             df_training, target_column, feature_columns, df_validation, ratio_training)
@@ -57,7 +61,7 @@ class RandomizedSearchCV(model_selection.RandomizedSearchCV):
             **kwargs: Other keyword arguments for original `fit`
 
         Returns:
-            sklearn_cv_pandas.Model
+            conjurer.ml.Model
         """
         df = df.sample(len(df))  # shuffle
         x = df[feature_columns].values
@@ -69,10 +73,13 @@ class RandomizedSearchCV(model_selection.RandomizedSearchCV):
 
 
 class GridSearchCV(model_selection.GridSearchCV):
-    def __init__(self, *args, **kwargs):
-        kwargs["return_train_score"] = True
-        kwargs["verbose"] = 10
-        super(GridSearchCV, self).__init__(*args, **kwargs)
+    def __init__(self, estimator, param_grid, scoring=None,
+                 n_jobs=None, pre_dispatch='2*n_jobs', cv=None, refit=True,
+                 verbose=10, error_score=numpy.nan, return_train_score=True):
+        super(GridSearchCV, self).__init__(
+            estimator, param_grid, scoring=scoring, n_jobs=n_jobs, pre_dispatch=pre_dispatch,
+            cv=cv, refit=refit, verbose=verbose, error_score=error_score, return_train_score=return_train_score
+        )
 
     def fit_sv_pandas(self, df_training, target_column, feature_columns,
                       df_validation=None, ratio_training=None, **kwargs):
@@ -87,7 +94,7 @@ class GridSearchCV(model_selection.GridSearchCV):
             **kwargs: Other keyword arguments for original `fit`
 
         Returns:
-            sklearn_cv_pandas.Model
+            conjurer.ml.Model
         """
         x, y, num_training, num_validation = _split_for_sv(
             df_training, target_column, feature_columns, df_validation, ratio_training)
@@ -108,7 +115,7 @@ class GridSearchCV(model_selection.GridSearchCV):
             **kwargs: Other keyword arguments for original `fit`
 
         Returns:
-            sklearn_cv_pandas.Model
+            conjurer.ml.Model
         """
         df = df.sample(len(df))  # shuffle
         x = df[feature_columns].values
